"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _postcss = require("postcss");

var _postcss2 = _interopRequireDefault(_postcss);

var _fs = require("fs");

var _fs2 = _interopRequireDefault(_fs);

var _globStream = require("glob-stream");

var _globStream2 = _interopRequireDefault(_globStream);

var _rcLoader = require("rc-loader");

var _rcLoader2 = _interopRequireDefault(_rcLoader);

var _stream = require("stream");

var _plugin = require("./plugin");

var _plugin2 = _interopRequireDefault(_plugin);

exports["default"] = function () {
  var _ref = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];

  var files = _ref.files;
  var config = _ref.config;

  var stylelintConfig = config || (0, _rcLoader2["default"])("stylelint");
  if (!stylelintConfig) {
    throw new Error("No stylelint config found");
  }

  var linter = new _stream.Transform({ objectMode: true });

  linter._transform = function (chunk, enc, callback) {
    if (files) {
      (function () {
        var filepath = chunk.path;
        _fs2["default"].readFile(filepath, "utf8", function (err, css) {
          if (err) {
            linter.emit("error", err);
          }
          lint({ css: css, filepath: filepath }, callback);
        });
      })();
    } else {
      lint({ css: chunk }, callback);
    }
  };

  function lint(_ref2, callback) {
    var css = _ref2.css;
    var filepath = _ref2.filepath;

    var processOptions = {};
    if (filepath) {
      processOptions.from = filepath;
    }
    (0, _postcss2["default"])().use((0, _plugin2["default"])(stylelintConfig)).process(css, processOptions).then(function (result) {
      callback(null, result);
    })["catch"](function (err) {
      linter.emit("error", new Error(err));
    });
  }

  if (files) {
    var fileStream = _globStream2["default"].create(files);
    return fileStream.pipe(linter);
  }

  return linter;
};

module.exports = exports["default"];