"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _utils = require("../../utils");

var ruleName = "root-no-standard-properties";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  rejected: function rejected(p) {
    return "Unexpected standard property \"" + p + "\" applied to \":root\"";
  }
});

exports.messages = messages;

exports["default"] = function (actual) {
  return function (root, result) {
    var validOptions = (0, _utils.validateOptions)(result, ruleName, { actual: actual });
    if (!validOptions) {
      return;
    }

    root.walkRules(function (rule) {
      if (rule.selector.indexOf(":root") === -1) {
        return;
      }

      rule.walkDecls(function (decl) {
        var prop = decl.prop;

        if ((0, _utils.cssPropertyIsVariable)(prop)) {
          return;
        }

        if (prop.indexOf("--") !== 0) {
          (0, _utils.report)({
            message: messages.rejected(prop),
            node: decl,
            result: result,
            ruleName: ruleName
          });
        }
      });
    });
  };
};