"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _balancedMatch = require("balanced-match");

var _balancedMatch2 = _interopRequireDefault(_balancedMatch);

var _styleSearch = require("./styleSearch");

var _styleSearch2 = _interopRequireDefault(_styleSearch);

/**
 * Search a CSS string for functions by name.
 * For every match, invoke the callback, passing the function's
 * "argument(s) string" (whatever is inside the parentheses)
 * as an argument.
 *
 * @param {string} source
 * @param {string} functionName - e.g. calc, color, rgba
 * @param {function} callback - Will be called once for every
 *   matching function found, with the function's "argument(s) string"
 *   and its starting index as the arguments
 */

exports["default"] = function (source, functionName, callback) {
  (0, _styleSearch2["default"])({ source: source, target: functionName, checkFunctionNames: true }, function (match) {
    if (source[match.endIndex] !== "(") {
      return;
    }
    var parensMatch = (0, _balancedMatch2["default"])("(", ")", source.substr(match.startIndex));
    callback(parensMatch.body, match.endIndex + 1);
  });
};

module.exports = exports["default"];